#[non_exhaustive]pub enum Event {
Shutdown {},
MenuItemClicked {
item_id: ItemId,
event: MouseEvent,
},
IconClicked {
area_id: AreaId,
event: MouseEvent,
},
NotificationClicked {
area_id: AreaId,
id: NotificationId,
event: MouseEvent,
},
NotificationDismissed {
area_id: AreaId,
id: NotificationId,
},
Clipboard {
event: ClipboardEvent,
},
CopyData {
ty: usize,
data: Vec<u8>,
},
Error {
error: Error,
},
}Expand description
An event emitted by the event loop.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Shutdown
Window has been shut down.
MenuItemClicked
The menu item identified by ItemId has been clicked.
IconClicked
An icon has been clicked.
NotificationClicked
Indicates that the notification with the associated token has been clicked.
NotificationDismissed
The notification associated with the given token either timed out or was dismissed.
Fields

id: NotificationIdThe identifier of the dismissed notification.
Clipboard
The system clipboard has been modified.
Fields

event: ClipboardEventThe generated clipboard event.
CopyData
Data was copied to the current process remotely using
Window::copy_data.
Error
A non-fatal error has been reported.